@@ -1,21 +1,20 @@
-import operator
-from functools import reduce
 from typing import List, cast
 
 import numpy as np
-import react_ipywidgets as react
-import react_ipywidgets.bqplot as bqplot
-import react_ipywidgets.ipyvuetify as v
-import react_ipywidgets.ipywidgets as w
+import reacton.bqplot as bqplot
+import reacton.ipyvuetify as v
+import reacton.ipywidgets as w
 
-from solara.components import PivotTable, ui_checkbox, ui_dropdown
-from solara.hooks import df_unique, max_unique, use_cross_filter, use_df_column_names
-from solara.hooks.dataframe import use_df_pivot_data
+import solara
+from solara.components import ui_checkbox, ui_dropdown
+from solara.hooks import use_cross_filter
+from solara.lab.hooks.dataframe import use_df_column_names
+from solara.lab.utils.dataframe import df_unique
 
 cardheight = "100%"
 
 
-@react.component
+@solara.component
 def ExpressionEditor(df, value: str, label="Custom expression", on_value=None, placeholder="Enter an expression", prepend_icon="function"):
     """Editor for expression for Vaex, on_value will only be triggered for valid expressions"""
 
@@ -28,9 +27,9 @@ def ExpressionEditor(df, value: str, label="Custom expression", on_value=None, p
         except Exception as e:
             return str(e)
 
-    value, set_value = react.use_state(value)
+    value, set_value = solara.use_state(value)
     error: List = []
-    error, set_error = react.use_state(cast(List, []))
+    error, set_error = solara.use_state(cast(List, []))
     set_error([get_error(value)])
 
     def on_value_local(value):
@@ -52,9 +51,9 @@ def ExpressionEditor(df, value: str, label="Custom expression", on_value=None, p
     )
 
 
-@react.component
+@solara.component
 def FilterCard(df):
-    filter, set_filter = use_cross_filter("filter-custom")
+    filter, set_filter = use_cross_filter(id(df), "filter-custom")
 
     with v.Card(elevation=2, height=cardheight) as main:
         with v.CardTitle(children=["Filter"]):
@@ -64,26 +63,26 @@ def FilterCard(df):
     return main
 
 
-@react.component
+@solara.component
 def Table(df, n=5):
     output_c = w.Output()
 
     def output():
         import ipywidgets as widgets
 
-        output_real: widgets.Output = react.get_widget(output_c)
+        output_real: widgets.Output = solara.get_widget(output_c)
         # don't rely on display, does not work in solara yet
         with output_real.hold_sync():
             output_real.outputs = tuple()
             output_real.append_display_data(df)
 
-    react.use_side_effect(output)
+    solara.use_side_effect(output)
     return output_c
 
 
-@react.component
+@solara.component
 def TableCard(df):
-    filter, set_filter = use_cross_filter(None)
+    filter, set_filter = use_cross_filter(id(df), "table")
     dff = df
     filtered = False
     if filter is not None:
@@ -104,12 +103,12 @@ def TableCard(df):
     return main
 
 
-@react.component
-def HistogramCard(df, column=None):
-    filter, set_filter = use_cross_filter("filter-histogram")
+@solara.component
+def HistogramCard(df, column=None, max_unique=100):
+    filter, set_filter = use_cross_filter(id(df), "filter-histogram")
     dff = df  # filter(df)
 
-    items = df.get_column_names()
+    items = use_df_column_names(df)
 
     with v.Card(elevation=2, height=cardheight) as main:
         with v.CardTitle(children=["Histogram"]):
@@ -124,7 +123,7 @@ def HistogramCard(df, column=None):
                             pass
                         with v.CardText():
                             column = items[0] if column not in items else column
-                            column = ui_dropdown(value=column, description="x", options=items)
+                            column = ui_dropdown(value=column, label="x", options=items)
             if column:
                 log = False
                 import vaex
@@ -147,7 +146,7 @@ def HistogramCard(df, column=None):
                         scale_x = bqplot.OrdinalScale()
                         x = np.where(x.astype("int8"), "true", "false")
                     elif dfg[column].dtype == str:
-                        scale_x = bqplot.OrdinalScale()
+                        scale_x = bqplot.OrdinalScale(domain=x.tolist())
                     else:
                         scale_x = bqplot.OrdinalScale()
                     if log:
@@ -156,7 +155,6 @@ def HistogramCard(df, column=None):
                         scale_y = bqplot.LinearScale()
 
                     def on_selected(selected):
-                        print("selected", selected)
                         if selected is not None:
                             if df[column].dtype == bool:
                                 value = [True, False][selected[0]]
@@ -168,24 +166,41 @@ def HistogramCard(df, column=None):
                             set_filter(None)
 
                     lines = bqplot.Bars(
+                        colors=["rgba(58, 130, 246, 0.5)"],
                         x=x.tolist(),
                         y=y.tolist(),
                         scales={"x": scale_x, "y": scale_y},
                         type="grouped",
-                        selected_style={"fill": "#f55"},
+                        selected_style={"fill": "rgba(58, 130, 246, 0.8)"},
                         on_selected=on_selected,
                         interactions={"click": "select"},
                     )
-                    x_axis = bqplot.Axis(scale=scale_x, label=column)
-                    y_axis = bqplot.Axis(scale=scale_y, orientation="vertical", label="count")
+                    x_axis = bqplot.Axis(
+                        scale=scale_x,
+                        label=column,
+                        grid_lines="none",
+                        color="rgba(0,0,0,0)",
+                        tick_style={
+                            "fill": "rgba(0,0,0,0.8)",
+                        },
+                    )
+                    y_axis = bqplot.Axis(
+                        scale=scale_y,
+                        orientation="vertical",
+                        label="count",
+                        color="rgba(0,0,0,0)",
+                        tick_style={
+                            "fill": "rgba(0,0,0,0.8)",
+                        },
+                    )
                     axes = [x_axis, y_axis]
                     bqplot.Figure(axes=axes, marks=[lines])
     return main
 
 
-@react.component
+@solara.component
 def ScatterCard(df, x=None, y=None, color=None):
-    filter, set_filter = use_cross_filter("filter-scatter")
+    filter, set_filter = use_cross_filter(id(df), "filter-scatter")
     dff = df
     if filter:
         dff = df[filter]
@@ -209,15 +224,15 @@ def ScatterCard(df, x=None, y=None, color=None):
                             xcol = x
                             if xcol is None:
                                 xcol = xcol if len(floats) == 0 else floats[0]
-                            xcol = ui_dropdown(value=xcol, description="x", options=floats)
+                            xcol = ui_dropdown(value=xcol, label="x", options=floats)
                             ycol = y
                             if ycol is None:
                                 ycol = ycol if len(floats) < 2 else floats[1]
-                            ycol = ui_dropdown(value=ycol, description="y", options=floats)
+                            ycol = ui_dropdown(value=ycol, label="y", options=floats)
                             ccol = color
                             if ccol is None:
                                 ccol = ccol if len(floats) < 3 else floats[0]
-                            ccol = ui_dropdown(value=ccol, description="Color", options=floats)
+                            ccol = ui_dropdown(value=ccol, label="Color", options=floats)
             if xcol and ycol:
                 if len(dff) > max_points:
                     v.Alert(
@@ -326,14 +341,14 @@ color_maps = [
 cardheight = "100%"
 
 
-@react.component
+@solara.component
 def HeatmapCard(df, x=None, y=None, debounce=True):
     limit_keys = "xmin xmax ymin ymax".split()
-    limits, set_limits = react.use_state(dict.fromkeys(limit_keys))
-    contrast, set_contrast = react.use_state([0.5, 99.5])
+    limits, set_limits = solara.use_state(dict.fromkeys(limit_keys))
+    contrast, set_contrast = solara.use_state([0.5, 99.5])
     # print("limits", limits)
     limits = limits.copy()
-    filter, set_filter = use_cross_filter("filter-heatmap")
+    filter, set_filter = use_cross_filter(id(df), "filter-heatmap")
     dff = df
     selection = filter
     # print("unfiltered", dff is df)
@@ -356,21 +371,20 @@ def HeatmapCard(df, x=None, y=None, debounce=True):
                             xcol = x
                             if xcol is None:
                                 xcol = xcol if len(floats) == 0 else floats[0]
-                            xcol = ui_dropdown(value=xcol, description="x", options=floats)
+                            xcol = ui_dropdown(value=xcol, label="x", options=floats)
                             ycol = y
                             if ycol is None:
                                 ycol = ycol if len(floats) == 0 else floats[1]
-                            ycol = ui_dropdown(value=ycol, description="y", options=floats)
-                            scheme = ui_dropdown(value=color_maps[0], options=color_maps)
+                            ycol = ui_dropdown(value=ycol, label="y", options=floats)
+                            scheme = ui_dropdown("Color map", value=color_maps[0], options=color_maps)
                             v.RangeSlider(v_model=contrast, on_v_model=set_contrast, label="Contrast", min=0, max=100)
-                            crossfilter_visible = ui_checkbox(value=False, description="Cross filter visible")
+                            crossfilter_visible = ui_checkbox(value=False, label="Cross filter visible")
 
             if xcol and ycol:
                 import vaex.jupyter
 
                 def updater(name):
-                    @react.use_memo
-                    def make(name):
+                    def make():
                         # def shared():  # all render functions get a shared function per 'name'
                         def setter(value):
                             def state_updater(state):
@@ -384,52 +398,48 @@ def HeatmapCard(df, x=None, y=None, debounce=True):
                             return setter
                         # return shared
 
-                    return make(name)
+                    return solara.use_memo(make, [name])
 
                 update_xmin = updater("xmin")
                 update_xmax = updater("xmax")
                 update_ymin = updater("ymin")
                 update_ymax = updater("ymax")
 
-                print("limits", limits)
-
                 # def update(name):
                 #     def update_single(value):
                 #         update_single_debouced(name, value)
                 #     return update_single
 
-                @react.use_memo
                 def minx(x):
                     values = [k.item() for k in dff[x].minmax()]
                     update_xmin(values[0])
                     update_xmax(values[1])
 
-                minx(xcol)
+                solara.use_memo(lambda: minx(xcol), [xcol])
 
-                @react.use_memo
+                # @solara.use_memo
                 def miny(y):
                     values = [k.item() for k in dff[y].minmax()]
                     update_ymin(values[0])
                     update_ymax(values[1])
 
-                miny(ycol)
+                solara.use_memo(lambda: miny(ycol), [ycol])
 
                 if all(limits[k] is not None for k in limit_keys):
                     # print("limits used", limits)
                     xrange = limits["xmin"], limits["xmax"]
                     yrange = limits["ymin"], limits["ymax"]
 
-                    @react.use_memo
-                    def cross_filter(crossfilter_visible, xrange, yrange):
+                    def cross_filter():
                         if crossfilter_visible:
                             visible_filter = (df[xcol] >= xrange[0]) & (df[xcol] <= xrange[1]) & (df[ycol] >= yrange[0]) & (df[ycol] <= yrange[1])
                             set_filter(visible_filter)
                         else:
                             set_filter(None)
 
-                    cross_filter(crossfilter_visible, xrange, yrange)
+                    solara.use_memo(cross_filter, [crossfilter_visible, xrange, yrange])
 
-                    # @react.use_memo
+                    # @solara.use_memo
 
                     def grid(xcol, ycol, limits):
                         vaex_limits = [xrange, yrange]
@@ -462,9 +472,9 @@ def HeatmapCard(df, x=None, y=None, debounce=True):
     return main
 
 
-@react.component
+@solara.component
 def SummaryCard(df):
-    filter, set_filter = use_cross_filter(None)
+    filter, set_filter = use_cross_filter(id(df), "summary")
     dff = df
     filtered = False
     if filter is not None:
@@ -490,14 +500,14 @@ def SummaryCard(df):
     return main
 
 
-@react.component
+@solara.component
 def DropdownCard(df, column=None):
     max_unique = 100
-    filter, set_filter = use_cross_filter("filter-dropdown")
+    filter, set_filter = use_cross_filter(id(df), "filter-dropdown")
     columns = use_df_column_names(df)
-    column, set_column = react.use_state(columns[0] if column is None else column)
+    column, set_column = solara.use_state(columns[0] if column is None else column)
     uniques = df_unique(df, column, limit=max_unique + 1)
-    value, set_value = react.use_state(None)
+    value, set_value = solara.use_state(None)
     # to avoid confusing vuetify about selecting 'None' and nothing
     magic_value_missing = "__missing_value__"
 
@@ -534,96 +544,3 @@ def DropdownCard(df, column=None):
                 v.Alert(type="warning", text=True, prominent=True, icon="mdi-alert", children=[f"Too many unique values, will only show first {max_unique}"])
 
     return main
-
-
-@react.component
-def PivotTableCard(df, x=[], y=[]):
-    # copy since we mutate
-    x = x.copy()
-    y = y.copy()
-    filter, set_filter = use_cross_filter("pivottable")
-    dff = df
-
-    def set_filter_from_pivot_selection(selection):
-        assert data is not None
-        filters = []
-        # print("selection", selection)
-        if "x" in selection:
-            sel = selection["x"]
-            for level in range(sel[0] + 1):
-                value = data["headers"]["x"][level][sel[1]]
-                column = data["x"][level]
-                if value is None:
-                    filters.append(df[column].ismissing())
-                else:
-                    filters.append(df[column] == value)
-
-        if "y" in selection:
-            sel = selection["y"]
-            for level in range(sel[0] + 1):
-                column = data["y"][level]
-                value = data["headers"]["y"][level][sel[1]]
-                if value is None:
-                    filters.append(df[column].ismissing())
-                else:
-                    filters.append(df[column] == value)
-        #         if filters:
-        #             expression = "&".join([k.expression for k in filters])
-        #         else:
-        #             expression = None
-        if filters:
-            #             otherfilters_expressions = [df[k] for k in otherfilters]
-            filter = reduce(operator.and_, filters[1:], filters[0])
-        #             return df[filter]
-        else:
-            filter = None
-        # print(filter)
-        set_filter(filter)
-
-    data = None
-    items = use_df_column_names(df)
-    with v.Card(elevation=2, style_="position: relative", height=cardheight) as main:
-        with v.CardTitle(children=["Pivot table"]):
-            pass
-        with v.CardText():
-            with v.Btn(v_on="x.on", icon=True, absolute=True, style_="right: 10px; top: 10px") as btn:
-                v.Icon(children=["mdi-settings"])
-            with v.Dialog(v_slots=[{"name": "activator", "variable": "x", "children": btn}]):
-                with v.Sheet():
-                    with v.Container(pa_4=True, ma_0=True):
-                        with v.Row():
-                            with v.Col():
-                                with v.Card(elevation=2):
-                                    with v.CardTitle(children=["Rows"]):
-                                        pass
-                                    with v.CardText():
-                                        for i in range(10):
-                                            col = ui_dropdown(value=x[i] if i < len(x) else None, description=f"Row {i}", options=items)
-                                            if col is None:
-                                                break
-                                            else:
-                                                if i < len(x):
-                                                    x[i] = col
-                                                else:
-                                                    x.append(col)
-                            with v.Col():
-                                with v.Card(elevation=2):
-                                    with v.CardTitle(children=["Columns"]):
-                                        pass
-                                    with v.CardText():
-                                        for i in range(10):
-                                            col = ui_dropdown(value=y[i] if i < len(y) else None, description=f"Column {i}", options=items)
-                                            if col is None:
-                                                break
-                                            else:
-                                                if i < len(y):
-                                                    y[i] = col
-                                                else:
-                                                    y.append(col)
-
-            import vaex
-
-            data = use_df_pivot_data(dff, x, y, vaex.agg.count(selection=filter))
-            PivotTable(d=data, on_selected=set_filter_from_pivot_selection)
-
-    return main
