@@ -2,7 +2,6 @@ import dataclasses
 import importlib.util
 import logging
 import os
-import pdb
 import pickle
 import sys
 import threading
@@ -11,6 +10,7 @@ from enum import Enum
 from pathlib import Path
 from typing import Any, Callable, Dict, List, Optional, cast
 
+import IPython.display
 import ipywidgets as widgets
 import reacton
 from ipywidgets import DOMWidget, Widget
@@ -21,7 +21,7 @@ import solara
 from ..util import cwd
 from . import kernel, reload, settings, websocket
 from .kernel import Kernel, WebsocketStreamWrapper
-from .utils import nested_get
+from .utils import nested_get, pdb_guard
 
 WebSocket = Any
 apps: Dict[str, "AppScript"] = {}
@@ -76,7 +76,7 @@ class AppScript:
                 self.app_name = default_app_name
         else:
             self.name = name
-        self.path: Path = Path(self.name)
+        self.path: Path = Path(self.name).resolve()
         try:
             context = get_current_context()
         except RuntimeError:
@@ -86,6 +86,7 @@ class AppScript:
         app_context = create_dummy_context()
         with app_context:
             app = self._execute()
+
         self._first_execute_app = app
         self._is_widget = isinstance(self._first_execute_app, widgets.Widget)
         app_context.close()
@@ -96,7 +97,7 @@ class AppScript:
         logger.info("Executing %s", self.name)
         app = None
         local_scope = {
-            "display": display,
+            "display": IPython.display.display,
             "__name__": "__main__",
             "__file__": str(self.path),
         }
@@ -191,6 +192,11 @@ class AppScript:
         if settings.ssg.build_path is None:
             settings.ssg.build_path = self.directory.parent.resolve() / "build"
 
+        # auto enable search if search.json exists
+        search_index_file = self.directory.parent / "assets" / "search.json"
+        if search_index_file.exists():
+            settings.search.enabled = True
+
         # this might be useful for development
         # but requires reloading of react in solara iself
         # for name, module in sys.modules.items():
@@ -492,7 +498,7 @@ def load_app_widget(app_state, app_script: AppScript, pathname: str):
         render_context = context.app_object
         with context:
             app_state = app_state_initial
-            try:
+            with pdb_guard():
                 widget, render_context = _run_app(
                     app_state,
                     app_script,
@@ -502,11 +508,6 @@ def load_app_widget(app_state, app_script: AppScript, pathname: str):
                 if render_context is None:
                     assert context.container is not None
                     context.container.children = [widget]
-            except Exception:
-                if settings.main.use_pdb:
-                    logger.exception("Exception, will be handled by debugger")
-                    pdb.post_mortem()
-                raise
 
             if render_context:
                 context.app_object = render_context
@@ -589,4 +590,5 @@ from . import patch  # noqa
 patch.patch()
 # the default app (used in solara-server)
 if "SOLARA_APP" in os.environ:
-    apps["__default__"] = AppScript(os.environ.get("SOLARA_APP", "solara.website.pages:Page"))
+    with pdb_guard():
+        apps["__default__"] = AppScript(os.environ.get("SOLARA_APP", "solara.website.pages:Page"))
