@@ -36,7 +36,7 @@ def get_cdn_url(path):
 
 def get_data(base_cache_dir: pathlib.Path, path):
     parts = path.replace("\\", "/").split("/")
-    store_path = path if len(parts) != 1 else pathlib.Path(path) / "__main"
+    store_path = path if len(parts) != 1 else pathlib.Path(path) / "__main.js"
 
     content = get_from_cache(base_cache_dir, store_path)
     if content:
@@ -52,10 +52,10 @@ def get_data(base_cache_dir: pathlib.Path, path):
         raise Exception(f"Could not load URL: {url}")
 
 
-def get_path(base_cache_dir: pathlib.Path, path):
+def get_path(base_cache_dir: pathlib.Path, path) -> pathlib.Path:
 
-    parts = path.split("/")
-    store_path = path if len(parts) != 1 else pathlib.Path(path) / "__main"
+    parts = path.replace("\\", "/").split("/")
+    store_path = path if len(parts) != 1 else pathlib.Path(path) / "__main.js"
     cache_path = base_cache_dir / store_path
 
     if cache_path.exists():
