@@ -12,6 +12,7 @@ import IPython.display
 import ipywidgets
 
 from . import app, reload, settings
+from .utils import pdb_guard
 
 logger = logging.getLogger("solara.server.app")
 
@@ -207,13 +208,8 @@ def WidgetContextAwareThread__init__(self, *args, **kwargs):
 def Thread_debug_run(self):
     if self.current_context:
         app.set_context_for_thread(self.current_context, self)
-    try:
+    with pdb_guard():
         Thread__run(self)
-    except Exception:
-        if settings.main.use_pdb:
-            logger.exception("Exception, will be handled by debugger")
-            pdb.post_mortem()
-        raise
 
 
 _patched = False
@@ -225,8 +221,7 @@ def patch():
         warnings.warn("patch() called twice")
         return
     _patched = True
-    IPython.display.display = display_solara
-    __builtins__["display"] = display_solara
+    __builtins__["display"] = IPython.display.display
 
     # the ipyvue.Template module cannot be accessed like ipyvue.Template
     # because the import in ipvue overrides it
