@@ -1,3 +1,5 @@
+import site
+import sys
 import uuid
 from enum import Enum
 from pathlib import Path
@@ -11,6 +13,11 @@ from .. import (  # noqa  # sidefx is that this module creates the ~/.solara dir
 )
 from ..util import get_solara_home
 
+if __file__.startswith(site.getuserbase()):
+    prefix = site.getuserbase()
+else:
+    prefix = sys.prefix
+
 
 class ThemeVariant(str, Enum):
     light = "light"
@@ -41,6 +48,10 @@ class SSG(pydantic.BaseSettings):
         env_file = ".env"
 
 
+class Search(pydantic.BaseSettings):
+    enabled: bool = False
+
+
 class Telemetry(pydantic.BaseSettings):
     mixpanel_token: str = "91845eb13a68e3db4e58d64ad23673b7"
     mixpanel_enable: bool = True
@@ -54,6 +65,19 @@ class Telemetry(pydantic.BaseSettings):
         env_file = ".env"
 
 
+class Assets(pydantic.BaseSettings):
+    cdn: str = "https://cdn.jsdelivr.net/npm/"
+    proxy: bool = True
+    proxy_cache_dir: Path = Path(prefix + "/share/solara/cdn/")
+    fontawesome_enabled: bool = True
+    fontawesome_path: str = "/font-awesome@4.5.0/css/font-awesome.min.css"
+
+    class Config:
+        env_prefix = "solara_assets_"
+        case_sensitive = False
+        env_file = ".env"
+
+
 class MainSettings(pydantic.BaseSettings):
     use_pdb: bool = False
     mode: str = "production"
@@ -71,7 +95,10 @@ main = MainSettings()
 theme = ThemeSettings()
 telemetry = Telemetry()
 ssg = SSG()
+search = Search()
+assets = Assets()
 
+assets.proxy_cache_dir.mkdir(exist_ok=True, parents=True)
 
 if telemetry.server_user_id == "not_set":
     home = get_solara_home()
