@@ -6,11 +6,9 @@ from typing import List, Union, cast
 from uuid import uuid4
 
 import anyio
-import solara
 import starlette.websockets
 import uvicorn.server
 import websockets.legacy.http
-from solara.server.threaded import ServerBase
 from starlette.applications import Starlette
 from starlette.middleware import Middleware
 from starlette.middleware.gzip import GZipMiddleware
@@ -19,6 +17,9 @@ from starlette.responses import HTMLResponse, JSONResponse
 from starlette.routing import Mount, Route, WebSocketRoute
 from starlette.staticfiles import StaticFiles
 
+import solara
+from solara.server.threaded import ServerBase
+
 from . import app as appmod
 from . import server, settings, telemetry, websocket
 from .cdn_helper import cdn_url_path, get_path
@@ -257,7 +258,7 @@ class StaticAssets(StaticFiles):
 
 class StaticCdn(StaticFiles):
     def lookup_path(self, path: str) -> typing.Tuple[str, typing.Optional[os.stat_result]]:
-        full_path = get_path(settings.assets.proxy_cache_dir, path)
+        full_path = str(get_path(settings.assets.proxy_cache_dir, path))
         return full_path, os.stat(full_path)
 
 
