@@ -1,10 +1,7 @@
 import solara
 from solara.alias import rv
 
-
-@solara.component
-def MarkdownEditor():
-    markdown_initial = """
+markdown_initial = """
 # Large
 ## Smaller
 
@@ -19,35 +16,26 @@ def MarkdownEditor():
 code = "formatted" and "supports highlighting"
 ```
 
-
-## Mermaid support!
-See [Mermaid docs](https://mermaid-js.github.io/)
-
-```mermaid
-graph TD;
-    A-->B;
-    A-->C;
-    B-->D;
-    C-->D;
-```
-
-
     """.strip()
+
+
+@solara.component
+def MarkdownEditor():
     markdown_text, set_markdown_text = solara.use_state(markdown_initial)
-    # with solara.GridFixed(columns=2) as main:
-    with solara.HBox(grow=True) as main:
-        with solara.VBox():
+    with solara.ColumnsResponsive(12, medium=6):
+        with solara.Column():
             solara.Markdown("# Input text")
             with solara.Padding(2):
                 with rv.Sheet(elevation=2):
-                    rv.Textarea(v_model=markdown_text, on_v_model=set_markdown_text, rows=30)
-        with solara.VBox():
+                    rv.Textarea(v_model=markdown_text, on_v_model=set_markdown_text, rows=20)
+        with solara.Column():
             solara.Markdown("# Renders like")
             with solara.Padding(2):
-                with rv.Sheet(elevation=2):
-                    solara.Markdown(markdown_text)
-
-    return main
+                solara.Markdown(markdown_text)
+        with solara.Sidebar():
+            with solara.Row():
+                solara.Button("Clear", on_click=lambda: set_markdown_text(""))
+                solara.Button("Reset ", on_click=lambda: set_markdown_text(markdown_initial))
 
 
 # create an alias of the Markdown Editor component so Solara can find it
