@@ -2,6 +2,7 @@ from typing import Callable
 
 import solara
 from solara.alias import rv
+from solara.server import settings
 
 
 @solara.component
@@ -16,12 +17,18 @@ def Header(
     # set states for menu
     with rv.AppBar(tag="header", flat=True, class_="bg-primary-fade padding-40", height="auto") as main:
         with rv.ToolbarTitle(class_="d-flex", style_="align-items:center"):
-            with solara.Button(icon=True, class_="hidden-md-and-up", on_click=lambda: on_toggle_left_menu and on_toggle_left_menu()):
-                rv.Icon(children=["mdi-menu"])
+            if route_current and len(route_current.children) > 0:
+                with solara.Button(icon=True, class_="hidden-md-and-up", on_click=lambda: on_toggle_left_menu and on_toggle_left_menu()):
+                    rv.Icon(children=["mdi-menu"])
             with solara.Link(path_or_route="/"):
                 solara.Image(router.root_path + "/static/assets/images/logo.svg")
         rv.Spacer()
 
+        if settings.search.enabled:
+            from solara_enterprise.search.search import Search
+
+            Search()
+
         # menu
         with rv.Html(tag="ul", class_="main-menu menu d-none d-md-flex"):
             for route in all_routes:
@@ -33,8 +40,7 @@ def Header(
         with rv.Btn(icon=True, tag="a", class_="d-none d-md-flex", attributes={"href": solara.github_url, "target": "_blank"}):
             rv.Icon(children=["mdi-github-circle"])
 
-        if route_current and len(route_current.children) > 0:
-            with solara.Button(icon=True, class_="hidden-md-and-up", on_click=lambda: on_toggle_right_menu and on_toggle_right_menu()):
-                rv.Icon(children=["mdi-menu"])
+        with solara.Button(icon=True, class_="hidden-md-and-up", on_click=lambda: on_toggle_right_menu and on_toggle_right_menu()):
+            rv.Icon(children=["mdi-menu"])
 
     return main
