@@ -13,10 +13,10 @@ df = plotly.data.tips()
 def Page():
     solara.provide_cross_filter()
     with solara.VBox() as main:
-        solara.lab.CrossFilterReport(df, classes=["py-2"])
-        solara.lab.CrossFilterSelect(df, "sex")
-        solara.lab.CrossFilterSelect(df, "time")
+        solara.CrossFilterReport(df, classes=["py-2"])
+        solara.CrossFilterSelect(df, "sex")
+        solara.CrossFilterSelect(df, "time")
     return main
 
 
-__doc__ += apidoc(solara.lab.CrossFilterSelect.f)  # type: ignore
+__doc__ += apidoc(solara.CrossFilterSelect.f)  # type: ignore
