@@ -5,18 +5,12 @@
 
 from typing import Any, Dict, Optional, cast
 
+import plotly
+
+import solara
 from solara.website.utils import apidoc
 
-try:
-    import vaex
-except ImportError:
-    vaex = None
-import solara
-
-if vaex is not None:
-    df = vaex.datasets.titanic()
-else:
-    df = None
+df = plotly.data.iris()
 
 
 @solara.component
@@ -32,21 +26,19 @@ def Page():
 
     column_actions = [solara.ColumnAction(icon="mdi-sunglasses", name="User column action", on_click=on_action_column)]
     cell_actions = [solara.CellAction(icon="mdi-white-balance-sunny", name="User cell action", on_click=on_action_cell)]
-    with solara.Div() as main:
-        solara.MarkdownIt(
-            f"""
-            ## Demo
+    solara.MarkdownIt(
+        f"""
+        ## Demo
 
-            Below we show display the titanic dataset, and demonstrate a user colum and cell action. Try clicking on the triple icon when hovering
-            above a column or cell. And see the following values changes:
+        Below we show display the titanic dataset, and demonstrate a user colum and cell action. Try clicking on the triple icon when hovering
+        above a column or cell. And see the following values changes:
 
-            * Column action on: `{column}`
-            * Cell action on: `{cell}`
+        * Column action on: `{column}`
+        * Cell action on: `{cell}`
 
-        """
-        )
-        solara.DataFrame(df, column_actions=column_actions, cell_actions=cell_actions)
-    return main
+    """
+    )
+    solara.DataFrame(df, column_actions=column_actions, cell_actions=cell_actions)
 
 
 __doc__ += apidoc(solara.DataFrame.f)  # type: ignore
